@@ -3,7 +3,7 @@
  * 
  * This file is a part of NSIS.
  * 
- * Copyright (C) 1999-2008 Nullsoft and Contributors
+ * Copyright (C) 1999-2009 Nullsoft and Contributors
  * 
  * Licensed under the zlib/libpng license (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,8 +23,10 @@
 #include "ui.h"
 #include "components.h"
 #include "exec.h"
+#include "plugin.h"
 #include "lang.h"
 #include "resource.h"
+#include "api.h"
 
 #define EXEC_ERROR 0x7FFFFFFF
 
@@ -41,17 +43,14 @@ typedef struct _stack_t {
 static stack_t *g_st;
 #endif
 
-exec_flags g_exec_flags;
-exec_flags g_exec_flags_last_used;
+exec_flags_t g_exec_flags;
+exec_flags_t g_exec_flags_last_used;
 
-struct {
-  exec_flags *flags;
-  void *ExecuteCodeSegment;
-  void *validate_filename;
-} plugin_extra_parameters = {
+extra_parameters plugin_extra_parameters = {
   &g_exec_flags,
   &ExecuteCodeSegment,
-  &validate_filename
+  &validate_filename,
+  &RegisterPluginCallback
 };
 
 #if defined(NSIS_SUPPORT_ACTIVEXREG) || defined(NSIS_SUPPORT_CREATESHORTCUT)
@@ -338,6 +337,10 @@ static int NSISCALL ExecuteEntry(entry *entry_)
                 exec_error++;
               }
             }
+            else
+            {
+              log_printf2("CreateDirectory: \"%s\" created",buf1);
+            }
             *p++ = c;
           }
         }
@@ -992,7 +995,7 @@ static int NSISCALL ExecuteEntry(entry *entry_)
               update_status_text(LANG_CANNOTFINDSYMBOL,buf0);
               log_printf3("Error registering DLL: %s not found in %s",buf0,buf1);
             }
-            if (!parm3) FreeLibrary(h);
+            if (!parm3 && Plugins_CanUnload(h)) FreeLibrary(h);
           }
           else
           {
@@ -1514,7 +1517,10 @@ static int NSISCALL ExecuteEntry(entry *entry_)
         log_dolog=parm1;
         log_printf2("logging set to %d",parm1);
 #if !defined(NSIS_CONFIG_LOG_ODS) && !defined(NSIS_CONFIG_LOG_STDOUT)
-        if (parm1) build_g_logfile();
+        if (parm1)
+          build_g_logfile();
+        else
+          log_write(1);
 #endif
       }
       else
